@@ -333,7 +333,42 @@ class Project(_Graphs, _Schematics, _SystemDiagrams, _DataFiles, _Optimization,
             show_files_dirs_dict[Name] = DirPath
         #end for
         return show_files_dirs_dict
-        #        
+        #
+    @property
+    def delete_all_datasets(self):#---------------------------------------------
+        self.awrde.Project.DataSetFolders.RemoveAll()
+        #
+    @property
+    def status_messages_list(self) -> list:#----------------------------------------------------
+        NumStatusGroups = self.awrde.Status.Groups.Count
+        StatusMsg_list = list()
+        for sg_idx in range(NumStatusGroups):
+            sg = self.awrde.Status.Groups[sg_idx]
+            if sg.Items.Count > 0:
+                for err_idx in range(sg.Items.Count):
+                    if 'Error' in str(mwo.mwStatusItemCategory(sg.Items[err_idx].Category)):
+                        StatusCategory = 'Error'
+                    elif 'Warning' in str(mwo.mwStatusItemCategory(sg.Items[err_idx].Category)):
+                        StatusCategory = 'Warning'
+                    elif 'Info' in str(mwo.mwStatusItemCategory(sg.Items[err_idx].Category)):
+                        StatusCategory = 'Information'
+                    else:
+                        StatusCategory = 'NA'
+                    #end if
+                    StatusMsg_list.append([StatusCategory, sg.Name, sg.Items[err_idx].Text])
+                #end for
+            #end if
+        #end for
+        return StatusMsg_list
+        #
+    @property
+    def clear_status_messages(self):#---------------------------------------------------
+        NumStatusGroups = self.awrde.Status.Groups.Count
+        StatusMsg_list = list()
+        for sg_idx in range(NumStatusGroups):
+            self.awrde.Status.Groups[sg_idx].RemoveAllItems()
+        #end for
+        #
     def _options_blacklist(self):#-------------------------------------------------------------------
         ''' lists of option names that cause errors'''
         self._project_options_blacklist = ['FaceInsetOptions']
@@ -436,7 +471,4 @@ class Project(_Graphs, _Schematics, _SystemDiagrams, _DataFiles, _Optimization,
         if sim_status != 0:  #Stop simulator if still running after maximum time
             self.awrde.Project.Simulator.stop()
         #end if    
-        #
-
-    
-    
\ No newline at end of file
+        #
\ No newline at end of file
