@@ -1022,28 +1022,43 @@ class _Equation():
                 break
             #end if
         #end if
-        
-        equation_split = expression.split(variable_type_str)
-        equation_name = equation_split[0]
-        equation_name = equation_name.lstrip()
-        equation_name = equation_name.rstrip()
-        if variable_type_str == ':':
-            equation_value = ''
-        else:
-            equation_value = equation_split[1]
-            equation_value = equation_value.lstrip()
-            equation_value = equation_value.rstrip()
-        #end if
+        #
+        try:
+            equation_split = expression.split(variable_type_str)
+            equation_name = equation_split[0]
+            equation_name = equation_name.lstrip()
+            equation_name = equation_name.rstrip()
+            if variable_type_str == ':':
+                equation_value = ''
+            else:
+                equation_value = equation_split[1]
+                equation_value = equation_value.lstrip()
+                equation_value = equation_value.rstrip()
+            #end if
+        except:
+            equation_name = 'NA'
+            equation_value = -999
+        #end try
         return equation_name, equation_value
         #
     def _determine_variable_type(self, expression: str):#----------------------------------------
         ''' returns variable type from the expression'''
-        variable_type_dict = {'=':'Variable definition', '<<':'Parameter definition', ':':'Display value'}
-        for variable_type_key in list(variable_type_dict):
-            if variable_type_key in expression:
-                variable_type_str = variable_type_dict[variable_type_key]
-                break
+        variable_type_dict = {'=':'Variable definition', '<<':'Parameter definition',
+                              ':':'Display value'}
+        found_it = False
+        try:
+            for variable_type_key in list(variable_type_dict):
+                if variable_type_key in expression:
+                    variable_type_str = variable_type_dict[variable_type_key]
+                    found_it = True
+                    break
+                #end if
             #end if
+        except:
+            variable_type_str = 'NA'
+        #end try
+        if not found_it:
+            variable_type_str = 'NA'
         #end if
         return variable_type_str
         #
