@@ -482,7 +482,12 @@ class _Measurement(_ProcessDefinitions):
     @property
     def measurement_doc_source(self) -> str:#---------------------------------------------
         '''Returns doucument source of the measurement'''
-        return self._meas.Source
+        meas_source = self._meas.Source
+        if '.' in meas_source:
+            meas_source_split = meas_source.split('.')
+            meas_source = meas_source_split[0]
+        #end if
+        return meas_source
         #
     @property
     def measurement_enabled(self) -> bool:#---------------------------------------
@@ -604,7 +609,7 @@ class _Measurement(_ProcessDefinitions):
         measurement trace data read back in base units.
         This routine scales the data to project units.
         '''
-        source_doc = self._meas.Source
+        source_doc = self.measurement_doc_source
         source_doc_type = self._source_doc_type(source_doc)
         if source_doc_type == 'Circuit Schematic':
             schem = self.awrde.Project.Schematics(source_doc)
