@@ -778,7 +778,7 @@ class _Optimization():
         #end if
         opt_goal_removed = False
         #
-        for i in range(len(self._optimization_goals_dict)):
+        for i in self._optimization_goals_dict.keys():
             temp_opt_goal = self._optimization_goals_dict[i]
             if optimization_goal_name == temp_opt_goal.goal_name:
                 dict_idx = i
@@ -1353,7 +1353,7 @@ class _Yield():
         #end if
         yield_goal_removed = False
         #
-        for i in range(len(self._yield_goals_dict)):
+        for i in self._yield_goals_dict.keys():
             temp_yield_goal = self._yield_goals_dict[i]
             if yield_goal_name == temp_yield_goal.goal_name:
                 dict_idx = i
@@ -1496,7 +1496,6 @@ class _Yield():
     def _build_yield_goal_dict(self):#----------------------------------------------
         self._yield_goals_dict = {}
         for goal_idx in range(self.awrde.Project.YieldGoals.Count):
-            print('hi')
             self._yield_goals_dict[goal_idx] = _Goal(self.awrde, goal_idx, 'Yield')
         #end for
         #
